//
//  RegionViewController.m
//  P51NV2Demo
//
//  Created by mac on 2019/8/6.
//  Copyright © 2019年 Robin. All rights reserved.
//

#import "RegionViewController.h"
#import "Utils.h"
#import <ASP51NV2SDK/ASP51NV2SDK.h>
@interface RegionViewController ()<ASP51NV2Delegate>
{
    int selectedSession;
    NSArray *dataArray;
}
@end

@implementation RegionViewController

#pragma mark - Lifecycle
- (void)viewDidLoad
{
    [super viewDidLoad];
    dataArray = [NSArray arrayWithObjects:@"Fcc Part", @"HONGKONG", @"Taiwai", @"Etsi En", @"Korea", @"Malaysia", @"China", @"South Africa", @"Brazil", @"Thailand", @"Singapore", @"Australia", @"India", @"Uruguay", @"Vietnam", @"Israel", @"Philippines", @"Indonesia", @"New Zealand", @"Japan", @"Peru", @"Russia", @"Custom", nil];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [ASP51NV2 sharedInstance].delegate = self;
    [Utils showLoadingView:@"" timeOut:df_TIMEOUT_DEFAULT];
    [self performSelector:@selector(onTickGetRegion) withObject:nil afterDelay:.3f];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [ASP51NV2 sharedInstance].delegate = nil;
}

#pragma mark - Private Method
- (void)onTickGetRegion
{
    [[ASP51NV2 sharedInstance] getRegion];
}

#pragma mark - ASP51NV2SDKSDK Delegate
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedRegion:(ASP51NV2RegionType)region executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        switch (region) {
            case ASP51NV2RegionTypeFccPart_15_247:
                selectedSession = 0;
                break;
            case ASP51NV2RegionTypeHongKong_920_925_MHZ:
                selectedSession = 1;
                break;
            case ASP51NV2RegionTypeTaiWan_922_928_MHZ:
                selectedSession = 2;
                break;
            case ASP51NV2RegionTypeEtsiEN_302_208_V1_4_1:
                selectedSession = 3;
                break;
            case ASP51NV2RegionTypeKorea_917_921_MHZ:
                selectedSession = 4;
                break;
            case ASP51NV2RegionTypeMalaysia_919_923_MHZ:
                selectedSession = 5;
                break;
            case ASP51NV2RegionTypeChina_920_925_MHZ:
                selectedSession = 6;
                break;
            case ASP51NV2RegionTypeSouthAfrica_915_919_MHZ:
                selectedSession = 7;
                break;
            case ASP51NV2RegionTypeBrazil_902_907_AND_915_928_MHZ:
                selectedSession = 8;
                break;
            case ASP51NV2RegionTypeThailand_920_925_MHZ:
                selectedSession = 9;
                break;
            case ASP51NV2RegionTypeSingapore_920_925_MHZ:
                selectedSession = 10;
                break;
            case ASP51NV2RegionTypeAustralia_920_926_MHZ:
                selectedSession = 11;
                break;
            case ASP51NV2RegionTypeIndia_865_867_MHZ:
                selectedSession = 12;
                break;
            case ASP51NV2RegionTypeUruguay_916_928_MHZ:
                selectedSession = 13;
                break;
            case ASP51NV2RegionTypeVietnam_920_925_MHZ:
                selectedSession = 14;
                break;
            case ASP51NV2RegionTypeIsrael_915_917_MHZ:
                selectedSession = 15;
                break;
            case ASP51NV2RegionTypePhilippines_918_920_MHZ:
                selectedSession = 16;
                break;
            case ASP51NV2RegionTypeIndonesia_923_925_MHZ:
                selectedSession = 17;
                break;
            case ASP51NV2RegionTypeNewzealand_921P5_928_MHZ:
                selectedSession = 18;
                break;
            case ASP51NV2RegionTypeJapan_916_921_MHZ_NO_LBT:
                selectedSession = 19;
                break;
            case ASP51NV2RegionTypePeru_916_928_MHZ:
                selectedSession = 20;
                break;
            case ASP51NV2RegionTypeRussia_916_921_MHZ:
                selectedSession = 21;
                break;
            case ASP51NV2RegionTypeCustom:
                selectedSession = 22;
                break;
            default:
                return;
        }
        dispatch_async(dispatch_get_main_queue(),^{
            [self.tableView reloadData];
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Region Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 didSetRegionExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        [Utils showAlert:@"Success" message:@"Region changed" view:self];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Region changed Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 changeNetworkState:(ASP51NV2NetworkState)state error:(NSError *)error
{
    switch (state) {
        case ASP51NV2NetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
        case ASP51NV2NetworkStateError:
            break;
        default:
            break;
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    [Utils showAlert:@"Error" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
}

#pragma mark - TableView DataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return dataArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    cell.textLabel.text = [dataArray objectAtIndex:indexPath.row];
    if(selectedSession == indexPath.row)
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    else
        cell.accessoryType = UITableViewCellAccessoryNone;
    return cell;
}

#pragma mark - TableView Delegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    selectedSession = (int)indexPath.row;
    [self.tableView reloadData];
}
#pragma mark - IBAction
- (IBAction)onClickButtonDone:(id)sender {
    [Utils showLoadingView:@"" timeOut:df_TIMEOUT_DEFAULT];
    ASP51NV2RegionType type;
    switch (selectedSession) {
        case 0:
            type = ASP51NV2RegionTypeFccPart_15_247;
            break;
        case 1:
            type = ASP51NV2RegionTypeHongKong_920_925_MHZ;
            break;
        case 2:
            type = ASP51NV2RegionTypeTaiWan_922_928_MHZ;
            break;
        case 3:
            type = ASP51NV2RegionTypeEtsiEN_302_208_V1_4_1;
            break;
        case 4:
            type = ASP51NV2RegionTypeKorea_917_921_MHZ;
            break;
        case 5:
            type = ASP51NV2RegionTypeMalaysia_919_923_MHZ;
            break;
        case 6:
            type = ASP51NV2RegionTypeChina_920_925_MHZ;
            break;
        case 7:
            type = ASP51NV2RegionTypeSouthAfrica_915_919_MHZ;
            break;
        case 8:
            type = ASP51NV2RegionTypeBrazil_902_907_AND_915_928_MHZ;
            break;
        case 9:
            type = ASP51NV2RegionTypeThailand_920_925_MHZ;
            break;
        case 10:
            type = ASP51NV2RegionTypeSingapore_920_925_MHZ;
            break;
        case 11:
            type = ASP51NV2RegionTypeAustralia_920_926_MHZ;
            break;
        case 12:
            type = ASP51NV2RegionTypeIndia_865_867_MHZ;
            break;
        case 13:
            type = ASP51NV2RegionTypeUruguay_916_928_MHZ;
            break;
        case 14:
            type = ASP51NV2RegionTypeVietnam_920_925_MHZ;
            break;
        case 15:
            type = ASP51NV2RegionTypeIsrael_915_917_MHZ;
            break;
        case 16:
            type = ASP51NV2RegionTypePhilippines_918_920_MHZ;
            break;
        case 17:
            type = ASP51NV2RegionTypeIndonesia_923_925_MHZ;
            break;
        case 18:
            type = ASP51NV2RegionTypeNewzealand_921P5_928_MHZ;
            break;
        case 19:
            type = ASP51NV2RegionTypeJapan_916_921_MHZ_NO_LBT;
            break;
        case 20:
            type = ASP51NV2RegionTypePeru_916_928_MHZ;
            break;
        case 21:
            type = ASP51NV2RegionTypeRussia_916_921_MHZ;
            break;
        case 22:
            type = ASP51NV2RegionTypeCustom;
            break;
        default:
            return;
    }
    [[ASP51NV2 sharedInstance] setRegion:type];

}

@end
